## Version 0.10.2

This release includes improvements to the LlamaBot components, specifically enhancing the functionality of the FTS index in the LanceDBDocStore.

### New Features

- Enabled the replacement of existing Full-Text Search (FTS) indexes to ensure up-to-date search capabilities in LanceDBDocStore. (973f850) (Eric Ma)

### Bug Fixes

- Updated the LlamaBot version in the pixi.lock file to maintain consistency with the latest software version, fixing dependency issues. (973f850) (Eric Ma)

### Deprecations

No deprecations were introduced in this version.
